@@ -57,7 +57,8 @@ class TMP3(TestCase):
         self.failUnlessEqual(self.mp3_4.info.bitrate, 9300)
 
     def test_notmp3(self):
-        self.failUnlessRaises(MP3Error, MP3, "README")
+        self.failUnlessRaises(
+            MP3Error, MP3, os.path.join('tests', 'data', 'empty.ofr'))
 
     def test_sketchy(self):
         self.failIf(self.mp3.info.sketchy)
